# tcpcon

tcpcon is a small uility (developed in Python) to test connections to a given host/port .

Expected to work on Windows, Linux and Mac .

## Motivation

Needed a quick way to test connections from systems where netcat is not available


## Requirements
- Python3

## How to install
```sh
pip instal tcpcon
```

## How to use
```sh
tcpcon www.sapo.pt 80
```
